@@ -2,12 +2,10 @@ from YamlBase.sql import SQLite, SQL
 
 
 class DBWorker:
+    cache_folder = "YamlBaseCache"
 
     def __init__(self, yaml):
-        self.db_data = yaml
-        self.conn = self.initialize_connection()
-        self.db_identifier = f"{self.db_data.db_info['ip']}_{self.db_data.db_info['db_type']}_" \
-                             f"{self.db_data.db_info['db_name']}"
+        pass
 
     def check_if_used(self):
         pass
@@ -15,7 +13,10 @@ class DBWorker:
     def initialize_connection(self) -> SQL:
         pass
 
-    def read_base_information(self):
+    def read_base_information_from_database(self):
+        pass
+
+    def read_base_information_from_config(self, cfg_path):
         pass
 
     def check_base_updates(self):
@@ -27,8 +28,12 @@ class DBWorker:
     def insert_new_table(self, new_table):
         pass
 
-    def generate_config(self):
+    def save_config(self):
         pass
 
     def check_insert_table_possibility(self, new_table_name):
         pass
+
+    def create_db_identifier(self) -> str:
+        return f"{self.db_data.db_info['ip']}_{self.db_data.db_info['db_type']}_" \
+                             f"{self.db_data.db_info['db_name']}".replace('/', '_').replace(':', '_')
