@@ -3,24 +3,23 @@
 import argparse
 import yaml
 import os
-from .ybase import YBase
+from YamlBase.ybase import YBase
 import sys
+import os
 
 
 def main():
 
-    sys.path.append('src/YamlBase')
+    os.chdir('../../')
 
     parser = argparse.ArgumentParser(description='This utility allows you to manage changes to the database using '
                                                  'configurations')
     parser.add_argument('-cfg_db', action='store', dest='cfg_path',
                         help='Path to yaml file with DB config')
-    parser.add_argument('-cfg_action', action='store', dest='action',
-                        help='Changes that should be made according config')
 
     args = parser.parse_args()
-
-    base = YBase(args.cfg_path, args.action)
+    print(os.listdir())
+    base = YBase('base_example.yml')
     base.do_actions()
 
 
