@@ -1,5 +1,7 @@
 """Main module file of YamlBase"""
 
+import os
+import yaml
 from YamlBase.dbworkers import SQLiteWorker
 from YamlBase.table_representation import Table
 from YamlBase.yaml_worker import YamlDataBaseWorker, YamlActionsWorker
@@ -9,15 +11,23 @@ from YamlBase.exceptions import InsertActionImpossibleError, DataBaseTypeNotFoun
 
 class YBase:
     """Main class of YamlBase"""
+
+    cache_folder = "YamlBaseCache"
+
     def __init__(self, path_to_yaml_db):
         """
         :param path_to_yaml_db: path to yaml representation of DataBase
         """
         self.yaml_config = YamlDataBaseWorker(path_to_yaml_db)
+        self.create_cache_folder_if_not_exist()
         folder_path = '/'.join(path_to_yaml_db.split('/')[:-1]) + '/'
         self.actions_config = YamlActionsWorker(folder_path+self.yaml_config.db_info['db_name'])
         self.db_worker = self.initialize_worker()
 
+    def create_cache_folder_if_not_exist(self):
+        if not os.path.exists(self.cache_folder):
+            os.mkdir(self.cache_folder)
+
     def initialize_worker(self):
         if self.yaml_config.db_info['db_type'].lower() == 'sqlite':
             return SQLiteWorker(self.yaml_config)
@@ -75,3 +85,6 @@ class YBase:
             raise RemoveActionImpossibleError()
 
         self.db_worker.remove_table(remove_table)
+
+    def init_config_action(self):
+        return self.db_worker.save_config()
