@@ -3,7 +3,7 @@ import yaml
 
 
 def test_convert_table_data_from_dict_to_table_obj():
-    with open('../test/test_base.yml') as f:
+    with open('./test/test_base.yml') as f:
         cfg = yaml.load(f, Loader=yaml.Loader)
 
     test_schema_name = 'main'
